@@ -180,6 +180,7 @@ public:
 		STATE_SLEEP,
 		STATE_START,
 		STATE_HANGUP,
+		STATE_LIBRESET,
 		STATE_FINAL,
 
 		STATE_STANDBY = STATE_DOWN,
@@ -291,6 +292,7 @@ public:
 		GET_LIBEXEC,
 		DROP_LIBEXEC,
 		STAT_LIBEXEC,
+		PROMPT_LIBEXEC,
 
 		// primary driver events
 
@@ -407,6 +409,15 @@ public:
 
 	} event_t;
 
+	typedef	enum
+	{
+		RESULT_SUCCESS,
+		RESULT_TIMEOUT,
+		RESULT_INVALID,
+		RESULT_PENDING,
+		RESULT_COMPLETE,
+	}	result_t;
+
 	typedef	struct
 	{
 		Line line;
@@ -464,6 +475,13 @@ public:
 				const char *exit;
 			}	libinput;
 
+			struct
+			{
+				const char *tid;
+				const char *voice;
+				const char *text;
+			}	libprompt;
+
 			struct
 			{
 				timeout_t duration;
@@ -530,7 +548,7 @@ public:
 		unsigned stack;
 		Line *lib;
 		int pfd;
-		int result;
+		result_t result;
 		int pid;
 		libaudio_t *libaudio;
 
@@ -1210,6 +1228,7 @@ public:
 	/**
 	 * Load a bayonne driver into memory.
 	 *
+	 * @param prefix path to load.
 	 * @param driver name to load.
 	 * @return NULL or pointer to loaded driver.
 	 */
@@ -1635,6 +1654,7 @@ protected:
 	bool stateSeize(Event *event);
 	bool stateRunning(Event *event);
 	bool stateLibexec(Event *event);
+	bool stateLibreset(Event *event);
 	bool stateThreading(Event *event);
 	bool stateHangup(Event *event);
 	bool stateCollect(Event *event);
@@ -1669,6 +1689,14 @@ public:
 	 */
 	const char *getExternal(const char *opt);
 
+	/**
+	 * Get event sequence id
+	 *
+	 * @return event sequence id.
+	 */
+	inline uint16 getEventSequence(void)
+		{return evseq;};
+
 protected:
 	/**
 	 * Return session id for interpreter session command.
@@ -1730,7 +1758,17 @@ protected:
 	 * @return true if in libexec
 	 * @param result code to set.
 	 */
-	bool setLibexec(int result);
+	bool setLibexec(result_t result);
+
+        /**
+         * Set the result of a libexec initiated process and execute a
+	 * reset timer interval.  This is used to schedule reset hang
+	 * time before resuming libexec. 
+         *
+         * @return true if in libexec
+         * @param result code to set.
+         */  
+	bool setLibreset(result_t result);
 
 public:
 	/**
