@@ -417,7 +417,7 @@ bool BayonneSession::putEvent(Event *event)
 	event_t id;
 
 	enter();
-	event->seq = evseq++;
+	event->seq = evseq;
 
 retry:
 	prior = state.handler;
@@ -455,6 +455,7 @@ retry:
 		goto retry;
 
 exiting:
+	++evseq;
 	release();
 	leave();
 	return rtn;
@@ -538,7 +539,17 @@ timeout_t BayonneSession::getMSecTimeout(const char *id)
 }
 
 #ifdef	HAVE_LIBEXEC
-bool BayonneSession::setLibexec(int result)
+bool BayonneSession::setLibreset(result_t result)
+{
+	if(!state.pid)
+		return false;
+
+	state.result = result;
+	setState(STATE_LIBRESET);
+	return true;
+}
+
+bool BayonneSession::setLibexec(result_t result)
 {
 	if(!state.pid)
 		return false;
@@ -550,7 +561,12 @@ bool BayonneSession::setLibexec(int result)
 
 #else
 
-bool BayonneSession::setLibexec(int result)
+bool BayonneSession::setLibreset(result_t result)
+{
+        return false;
+} 
+
+bool BayonneSession::setLibexec(result_t result)
 {
 	return false;
 }
