@@ -41,26 +41,98 @@ bool BayonneSession::stateLibexec(Event *event)
 {
 	char buf[256];
 	const char *cp;
-	char *up;
+	char *up, *p;
 	unsigned opt;
 	char evtmsg[65];
+	char bts[8];
+	unsigned count = 0;
 
 	switch(event->id)
 	{
+	case PROMPT_LIBEXEC:
+		if(!state.pid)
+			return false;
+		if(stricmp(var_tid, event->libprompt.tid))
+			return false;
+		if(state.pfd < 0)
+			return true;
+		if(*dtmf_digits)
+		{
+			state.result = RESULT_PENDING;
+			goto start;
+		}
+		memset(&state.audio, 0, sizeof(state.audio));
+		audio.offset = NULL;
+		state.audio.exitkey = true;
+		state.audio.mode = Audio::modeReadAny;
+		cp = getAudio();
+		if(cp)
+		{
+			slog.error("%s: %s", logname, cp);
+			if(signalScript(SIGNAL_FAIL))
+			{
+				setRunning();
+				return true;
+			}
+			state.result = RESULT_INVALID;
+			goto start;
+		}
+		if(event->libprompt.voice)
+		{
+			cp = event->libprompt.voice;
+			snprintf(bts, sizeof(bts), "%s", cp);
+			p = strchr(bts, '/');
+			if(p)
+				*p = 0;
+			audio.translator = BayonneTranslator::get(bts);
+			if(!audio.translator)
+			{
+				state.result = RESULT_INVALID;
+				goto start;
+			}
+			cp = audio.getVoicelib(cp);
+			if(!cp)
+			{
+				state.result = RESULT_INVALID;
+				goto start;
+			}
+			audio.voicelib = cp;
+		}
+		snprintf(state.libaudio->text, MAX_LIBINPUT, "%s", event->libprompt.text);
+		cp = strtok_r(state.libaudio->text, " \t\r\n", &p);
+		while(cp && count < (MAX_LIBINPUT / 2 - 1))
+		{
+			state.libaudio->list[count++] = cp;
+			cp = strtok_r(NULL, " \t\r\n", &p);
+		}
+		state.libaudio->list[count] = NULL;
+		state.libaudio->line.argc = count;
+		state.libaudio->line.args = state.libaudio->list;
+		state.libaudio->line.cmd = "prompt";
+		cp = audio.translator->speak(this, &state.libaudio->line);
+		if(cp)
+		{
+			slog.error("%s: %s", logname, cp);
+			state.result = RESULT_INVALID;
+			goto start;
+		}
+		setState(STATE_PLAY);
+		return true;				
 	case GET_LIBEXEC:
-		memset(&state.input, 0, sizeof(state.input));
 		if(!state.pid)
                         return false;
                 if(stricmp(var_tid, event->libinput.tid))
                         return false;
                 if(state.pfd < 0)
                         return true;
+		memset(&state.input, 0, sizeof(state.input));
 		state.timeout = state.input.interdigit = event->libinput.timeout;
 		state.input.count = state.input.required = event->libinput.count;
 		state.input.exit = event->libinput.exit;
 		setState(STATE_INPUT);
 		return true;
 	case ENTER_STATE:
+start:
 		if(state.lib && getLine() != state.lib)
 		{
 			newTid();
@@ -83,7 +155,7 @@ bool BayonneSession::stateLibexec(Event *event)
 				write(state.pfd, buf, strlen(buf));
 			}
 	
-			if(!state.result && *dtmf_digits)
+			if(state.result == RESULT_SUCCESS && *dtmf_digits)
 			{
 				snprintf(buf, sizeof(buf), "DIGITS: %s\n", dtmf_digits);
 				write(state.pfd, buf, strlen(buf));
@@ -93,7 +165,7 @@ bool BayonneSession::stateLibexec(Event *event)
 
 			snprintf(buf, sizeof(buf), "RESULT: %d\n\n", state.result);
 			::write(state.pfd, buf, strlen(buf));
-			state.result = 0;
+			state.result = RESULT_SUCCESS;
 		}
 		strcpy(audio.var_position, "00:00:00.000");
 timer:
@@ -107,7 +179,7 @@ timer:
 	case ENTER_LIBEXEC:
 		if(stricmp(var_tid, event->libexec.tid))
 			return false;
-		state.result = 0;
+		state.result = RESULT_SUCCESS;
 		state.pid = event->libexec.pid;
 		state.pfd = ::open(event->libexec.fname, O_RDWR);
 		remove(event->libexec.fname);
@@ -177,14 +249,14 @@ timer:
 		write(state.pfd, buf, strlen(buf));
 		if(cp)
 		{
-			state.result = 0;
+			state.result = RESULT_SUCCESS;
 			write(state.pfd, cp, strlen(cp));
 		}
 		else
-			state.result = 1;
+			state.result = RESULT_INVALID;
 		snprintf(buf, sizeof(buf), "\nRESULT: %d\n\n", 
 			state.result);
-		state.result = 0;
+		state.result = RESULT_SUCCESS;
 		write(state.pfd, buf, strlen(buf));
 		return true;
 	case ARGS_LIBEXEC:
@@ -304,6 +376,29 @@ timer:
 	return enterCommon(event);
 }
 		
+bool BayonneSession::stateLibreset(Event *event)
+{
+	switch(event->id)
+	{
+	case ENTER_STATE:
+		if(thread)
+		{
+			delete thread;
+			thread = NULL;
+		}
+		startTimer(reset_timer);
+		return true;
+	case TIMER_EXPIRED:
+		clrAudio();
+		if(setLibexec(state.result))
+			return true;
+		setRunning();
+		return true;
+	}
+
+	return enterCommon(event);
+}
+
 #else
 
 bool BayonneSession::stateLibexec(Event *event)
@@ -311,6 +406,11 @@ bool BayonneSession::stateLibexec(Event *event)
 	return false;
 }
 
+bool BayonneSession::stateLibreset(Event *event)
+{
+	return false;
+}
+
 #endif
 
 bool BayonneSession::stateReset(Event *event)
@@ -545,7 +645,7 @@ bool BayonneSession::stateInput(Event *event)
 			goto input;
 		dtmf_digits[0] = 0;
 		digit_count = 0;
-		if(setLibexec(1))
+		if(setLibexec(RESULT_TIMEOUT))
 			return true;
 		setSymbol(state.input.var, "", state.input.size);
 		if(scriptEvent("input:timeout"))
@@ -581,7 +681,7 @@ bool BayonneSession::stateInput(Event *event)
 			dtmf_digits[0] = 0;
 			digit_count = 0;
 
-			if(setLibexec(2))
+			if(setLibexec(RESULT_INVALID))
 				return true;
 
 			if(!scriptEvent("input:invalid"))
@@ -592,16 +692,13 @@ bool BayonneSession::stateInput(Event *event)
 			return true;
 		}
 input:
-#ifdef	HAVE_LIBEXEC
-		if(state.pid)
+		if(setLibexec(RESULT_SUCCESS))
 		{
-			state.result = 0;
 			if(state.input.exit && strchr(state.input.exit, dtmf_digits[digit_count - 1]))
 				dtmf_digits[--digit_count] = 0;
-			setState(STATE_LIBEXEC);
 			return true;
 		}
-#endif
+
 		size = count;
 		if(state.input.format)
 		{
@@ -950,6 +1047,8 @@ bool BayonneSession::statePlay(Event *event)
 
 		if(digit_count && state.audio.exitkey)
 		{
+			if(setLibreset(RESULT_PENDING))
+				return true;
 			advance();
 			setRunning();
 		}
@@ -986,12 +1085,16 @@ exitkey:
                         *dtmf_digits = key;
                         dtmf_digits[1] = 0;
                         digit_count = 1;
+			if(setLibreset(RESULT_PENDING))
+				return true;
                         advance();
                         setRunning();
                         return true;
                 }
 		break;
 	case AUDIO_IDLE:
+		if(setLibreset(RESULT_COMPLETE))
+			return true;
 		advance();
 		setRunning();
 		return true;
@@ -1567,6 +1670,8 @@ bool BayonneSession::stateRunning(Event *event)
 			if(seizure != CHILD_RUNNING)
 				strcpy(var_pid, "none");
 		}
+		if(state.pid)
+			newTid();
 		if(thread)
 		{
 			delete thread;
