@@ -73,7 +73,7 @@ void Session::stopTimer(void)
 
 tpport_t Session::getLocalPort(void)
 {
-	Driver *d = dynamic_cast<Driver *>(driver);
+	Driver *d = (Driver *)(driver);
 
 	return d->rtp_port + (4 * timeslot);
 }	
