@@ -53,6 +53,10 @@ BayonneDriver(driver, KEYS, "soundcard", true)
 	active = Audio::hasDevice(device);
 	keyboard = NULL;
 
+#ifdef	HAVE_FOX
+	desktop = NULL;
+#endif
+
 	cp = getLast("level");
 	if(cp)
 		audio_level = atoi(cp);
@@ -71,15 +75,37 @@ BayonneDriver(driver, KEYS, "soundcard", true)
 
 void Driver::startDriver(void)
 {
-	keyboard = new Keyboard(this);
+	bool kb = true;
 	msgport = new BayonneMsgport(this);
 
+#ifdef	HAVE_FOX
+	const char *d = Process::getEnv("DISPLAY");
+	if(d && *d)
+	{
+		desktop = new Desktop(getFirst());
+//		kb = false;
+	}
+#endif
+
+#ifdef  WIN32
+	if(kb)
+	        keyboard = new Keyboard(this);
+#else
+        if(getppid() > 1 && kb)
+                keyboard = new Keyboard(this);
+#endif   
+
 	timeslot = ts_used;
 	new Session(0, device);
 	count = ts_used - timeslot;
 
 	msgport->start();
-	keyboard->start();
+	if(keyboard)
+		keyboard->start();
+#ifdef	HAVE_FOX
+	if(desktop)
+		desktop->start();
+#endif
 	BayonneDriver::startDriver();
 }
 
@@ -90,6 +116,13 @@ void Driver::stopDriver(void)
 		delete keyboard;
 		keyboard = NULL;
 	}
+#ifdef	HAVE_FOX
+	if(desktop)
+	{
+		delete desktop;
+		desktop = NULL;
+	}
+#endif
 	BayonneDriver::stopDriver();
 }
 
