@@ -353,6 +353,11 @@ const char *Checks::chkLibexec(Line *line, ScriptImage *img)
 
 const char *Checks::chkVoicelib(Line *line, ScriptImage *img)
 {
+	char path[256];
+	char lang[64];
+	const char *cp;
+	char *p;
+
 	if(getMember(line))
 		return "voice library has no members";
 
@@ -362,9 +367,49 @@ const char *Checks::chkVoicelib(Line *line, ScriptImage *img)
 	if(line->argc != 1)
 		return "voice library argument must be specified";
 
-	if(*line->args[0] == '%' || *line->args[0] == '#' || *line->args[0] == '&')
+	cp = line->args[0];
+
+	if(*cp == '%' || *cp == '#' || *cp == '&')
 		return "voice library cannot be variable";
 
+	if(!strchr(cp, '/'))
+		return "voice library missing voice";
+
+	if(strchr(cp, '/') != strrchr(cp, '/'))
+		return "invalid voice library path";
+
+	if(strchr(cp, '.'))
+		return "invalid voice library path";		
+
+	snprintf(path, sizeof(path), "%s/%s", 
+		keypaths.getLast("prompts"), cp);
+
+	if(!stricmp(line->cmd, "voicelib"))
+	{
+		setString((char *)line->cmd, 9, cp);
+		p = strchr(line->cmd, '/');
+		if(p)
+			*p = 0;
+	}
+
+	if(isDir(path))
+		return NULL;
+
+	if(cp[2] != '_')
+		return "invalid voice library";
+
+	lang[0] = cp[0];
+	lang[1] = cp[1];
+	cp = strchr(cp, '/');
+	snprintf(lang + 2, sizeof(lang) - 2, "%s", cp);
+	snprintf(path, sizeof(path), "%s/%s",
+		keypaths.getLast("prompts"), lang);
+
+	if(!isDir(path))
+		return "unknown voice library";
+	
+	strcpy((char *)line->args[0], lang);
+	
 	return NULL;
 }
 
