@@ -58,7 +58,7 @@ using namespace std;
 #define	RUN_FILES	"C:\\Program Files\\GNU Telephony\\Bayonne Logs"
 #define	LIBEXEC_FILES	"C:\\Program Files\\GNU Telephony\\Bayonne Libxec"
 
-#ifdef	DEBUG
+#ifdef	_DEBUG
 #define	LIBDIR_FILES	"C:\\Program Files\\GNU Telephony\\CAPE Framework\\debug"
 #define	MODULE_FILES	LIBDIR_FILES
 #define	DRIVER_FILES	LIBDIR_FILES
@@ -331,7 +331,7 @@ static void commonConfig(void)
 void testConfig(char *argv0)
 {
 #ifdef	WIN32
-#ifdef	DEBUG
+#ifdef	_DEBUG
 	keypaths.setValue("phrases", "Debug");
 	keypaths.setValue("drivers", "Debug");
 	keypaths.setValue("modules", "Debug");
@@ -664,6 +664,21 @@ skip:
 		exit(-1);
 	}
 
+#ifdef	WIN32
+	Process::setEnv("DISPLAY", "yes", true);
+	if(!stricmp(driver, "console"))
+	{
+		Process::setEnv("DISPLAY", "", true);
+		driver = "soundcard";
+	}
+#else
+	if(!stricmp(driver, "console"))
+	{
+		Process::setEnv("DISPLAY", "", true);
+		driver = "soundcard";
+	}
+#endif
+
 	ext = strchr(driver, ':');
 	if(ext)
 	{
@@ -685,7 +700,7 @@ skip:
  
 	prefix = keypaths.getLast("drivers");
 #ifdef	WIN32
-	snprintf(path, sizeof(path), "%s/%s." RLL_SUFFIX, prefix, driver);
+	snprintf(path, sizeof(path), "%s/%s" RLL_SUFFIX, prefix, driver);
 #else
 	if(!strnicmp(prefix, "..", 2))
 		snprintf(path, sizeof(path), "%s/%s/.libs/%s.ivr", prefix, driver, driver);
@@ -693,6 +708,12 @@ skip:
 		snprintf(path, sizeof(path), "%s/%s.ivr", prefix, driver);
 #endif
 	keyoptions.setValue("driver", path);
+
+	if(!canAccess(path))
+	{
+		cerr << "server exiting; " << path << " missing" << endl;
+		exit(-1);
+	}
 	
 	while(*argv)
 	{
@@ -701,7 +722,7 @@ skip:
 		{
 			prefix = keypaths.getLast("modules");
 #ifdef	WIN32
-			snprintf(path, sizeof(path), "%s/%s." RLL_SUFFIX, prefix, *argv);
+			snprintf(path, sizeof(path), "%s/%s" RLL_SUFFIX, prefix, *argv);
 #else
 			if(!strnicmp(prefix, "..", 2))
 				snprintf(path, sizeof(path), "%s/%s/.libs/%s.dso", prefix, *argv, *argv);
