@@ -296,8 +296,21 @@ post:
 			else
 				slog.debug("libexec exiting; tsid=%s", tsid);
 		}
+		else if(!stricmp(cmd, "prompt") || (strchr(cmd, '/') && strchr(cmd, '/') == strrchr(cmd, '/')))
+		{
+			event.id = PROMPT_LIBEXEC;
+			event.libprompt.tid = tsid;
+			event.libprompt.voice = NULL;
+			if(strchr(cmd, '/'))
+				event.libprompt.voice = cmd;
+			event.libprompt.text = strtok_r(NULL, "", &tok);
+			if(!s->postEvent(&event))
+				slog.error("libexec unknown or invalid voice request %s", cmd);
+			else
+				slog.debug("libexec prompt; tsid=%s", tsid);
+		}
 		else
-			slog.error("libexec unknown request; cmd=%s", cmd);
+			slog.error("libexec unknown command %s", cmd);
 	}
 }
 
