@@ -698,34 +698,22 @@ bool Methods::scrCleardigits(void)
 bool Methods::scrVoicelib(void)
 {
 	const char *lib = getValue(NULL);
-	char bts[8];
-	char *p;
 	BayonneTranslator *t;
+	Line *line = getLine();
 
-	snprintf(bts, sizeof(bts), "%s", lib);
-	p = strchr(bts, '/');
-	if(p)
-		*p = 0;
-	t = BayonneTranslator::get(bts);
+	t = BayonneTranslator::get(line->cmd);
 	if(!t)
 	{
-		slog.error("language %s not loaded", bts);
+		slog.error("language %s not loaded", line->cmd);
 		error("voicelib-invalid");
 		return true;
 	}
 
-	lib = audio.getVoicelib(lib);
-	if(lib == NULL)
-	{
-		slog.error("voice library %s invalid", lib);
-		error("voicelib-invalid");
-	}
-	else
-	{
-		translator = t;
-		voicelib = lib;
-		advance();
-	}
+	// we depend on compile-time check to validate voicelib command
+
+	translator = t;
+	voicelib = lib;
+	advance();
 	return true;
 }
 
