@@ -365,12 +365,6 @@ int main(int argc, char **argv)
 {
 	char *cp;
 
-#if defined(WIN32) && defined(DEBUG)
-        int tmpFlag = _CrtSetDbgFlag( _CRTDBG_REPORT_FLAG );
-        tmpflag |= _CRTDBG_ALLOC_MEM_DF|_CRTDBG_CHECK_ALWAYS_DF|_CRTDBG_CHECK_CRT_DF;
-	_CrtSetDbgFlag( tmpFlag );
-#endif   
-
         if(argc < 2)
         {
                 cerr << "use: bayonne --option [args...]" << endl;
