@@ -94,6 +94,40 @@ public:
 	void clear(char *data, unsigned size);
 };
 
+class PersistProperty : public ScriptProperty, public Bayonne
+{
+private:
+	static ScriptSymbols syms;
+	static ThreadLock lock;
+	static bool loaded;
+
+#define	PERSIST_CACHE_SIZE 64
+
+	typedef	struct
+	{
+		char cache[PERSIST_CACHE_SIZE];
+		Symbol *sym;
+	} persist_t;
+
+public:
+	PersistProperty();
+
+	void set(const char *data, char *temp, unsigned size);
+
+	static bool remap(const char *id, char *save, const char *val = "");
+
+	static bool refresh(Symbol *sym, const char *ind, const char *val = "");
+
+	static bool test(const char *key);
+
+	static void save(void);
+
+	static void load(void);
+
+	static inline unsigned getSize(void)
+		{return sizeof(persist_t) + sizeof(ScriptProperty *);};
+};
+
 class TimeslotProperty : public ScriptProperty, public Bayonne
 {
 public:
@@ -132,6 +166,7 @@ protected:
 	static bool testDriver(ScriptInterp *interp, const char *v);
 	static bool testVoice(ScriptInterp *interp, const char *v);
 	static bool testLang(ScriptInterp *interp, const char *v);
+	static bool testKey(ScriptInterp *interp, const char *v);
 
 public:
 	static void process(void);
@@ -194,11 +229,13 @@ public:
 	bool scrSignal(void);
 	bool scrFailsignal(void);
 	bool scrDial(void);
+	bool scrKey(void);
 };
 
 class Checks : public ScriptChecks, public Bayonne
 {
 public:
+	const char *chkKey(Line *line, ScriptImage *img);
 	const char *chkCDR(Line *line, ScriptImage *img);
 	const char *chkTonegen(Line *line, ScriptImage *img);
 	const char *chkRegister(Line *line, ScriptImage *img);
